import java.util.*;
/**
 * Dies ist ein einfacher Social Bot, der posten und 
 * alle Beitrge auf seiner eigene Pinnwand Liken kann.
 */
public class EinfacherSocialBot 
{
    private String username;
    private String password;
    private NetzwerkZugriff socialbotnet;

    /**
     * EinfacherSocialBot Konstruktor
     *
     * @param usernameNeu username
     * @param passwordNeu password
     */
    public EinfacherSocialBot(String usernameNeu, String passwordNeu) {
        this.username = usernameNeu;
        this.password = passwordNeu;
        this.socialbotnet = new NetzwerkZugriff("https://www.socialbotnet.de");
    }
    
    /**
     * Posts der eigenen Pinwand abrufen und auf der Konsole (unformatiert) ausgeben.
     */
    public void postsAusgeben() 
    {
        String antwort;
        
        antwort=socialbotnet.GETAnfrageSenden("/api/pinnwand/"+this.username);
        
        System.out.println(antwort);
        
    }
    
    /**
     * Posts der eigenen Pinwand abrufen und auf der Konsole formatiert ausgeben.
     */
    public void postsFormatiertAusgeben() 
    {
        String antwort;
        // Alle Posts auf der eigenen Pinnwand abrufen
        antwort=socialbotnet.GETAnfrageSenden("/api/pinnwand/"+this.username);
        // Mit dem vorgefertigten JSON-Parser zu einem Feld (Array) aus Objekten der Klasse Post umwandeln.
        // Array ist eine Alternative zu ArrayList ein Feld in Java umzusetzen.
        Post[] postsAlsArray;
        postsAlsArray = AntwortParser.zuPostArray(antwort);
        
        //Wer sich sicherer mit einer ArrayList fhlt, kann alle Elemente des Arrays in die ArrayList einfgen
        ArrayList<Post> posts;
        posts = new ArrayList<Post>();
        for(Post p: postsAlsArray)
        {
            posts.add(p);
        }
        
        //Nun die formatierte Ausgabe
        for(Post p: postsAlsArray)
        {
            System.out.println("id: " + p.getId());
            System.out.println("likedBy: " + p.getLikedBy());
            System.out.println("message: " + p.getMessage());
            System.out.println("publischingDate: " + p.getPublishingDate());
            System.out.println("userID und userName: " + p.getUserId() + " " + p.getUsername());
            System.out.println("wall: " + p.getWall().getUsername());
            System.out.println("----------------------------------------");
            
        }
   }
   

    /**
     * Methode zum Postet eine Nachricht.
     *
     * @param nachricht Nachricht
     */
    public void posten(String nachricht) 
    {
        // Daten mssen zuerst in POST-Anfrage geschrieben werden
        // Fr /api/post ist das username, password, und message
        socialbotnet.POSTAnfrageVorbereiten("username", this.username);
        socialbotnet.POSTAnfrageVorbereiten("password", this.password);
        socialbotnet.POSTAnfrageVorbereiten("message", nachricht);
        socialbotnet.POSTAnfrageSenden("/api/post");
    }
    
    /**
     * Methode zum Liken eine Nachricht.
     *
     * @param id id der Nachricht
     */
    public void liken(int id) 
    {
        // An /api/like mssen username, password und postid mitgeschickt werden
        socialbotnet.POSTAnfrageVorbereiten("username", this.username);
        socialbotnet.POSTAnfrageVorbereiten("password", this.password);
        socialbotnet.POSTAnfrageVorbereiten("postid", id);
        socialbotnet.POSTAnfrageSenden("/api/like");
    }
    
    /**
     * Methode zum Liken der eigenen Pinnwand.
     */
    public void eigenePinnwandLiken() {
        // Alle Posts auf der eigenen Pinnwand abrufen
        String antwort = socialbotnet.GETAnfrageSenden("/api/pinnwand/"+this.username);
        // Mit dem vorgefertigten JSON-Parser zu gewohnten Objekten umwandeln.
        Post[] posts = AntwortParser.zuPostArray(antwort);
        // Iteration ber die einzelnen Posts
        for (int i=0; i<posts.length; i++) {
            Post post = posts[i];
            
            // Von dem Post wird die ID als Parameter zum Liken bentigt
            int id = post.getId();
            liken(id);
        }
    }
}
